@@ -103,8 +103,6 @@ class VectorIndex(Index):
         if req_type == 'delete':
             self.delete_data(msg.delete.ids)
         elif req_type == 'index':
-            if self.full:
-                raise RuntimeError("Index is full, cannot accept upserts")
             VectorIndex.validate_ids(msg.index.ids)
             data = VectorIndex.downcast_data(load_numpy(msg.index.data))
             if len(data.shape) == 1:
