@@ -17,8 +17,22 @@ __all__ = ["GRPCClient"]
 
 
 class GRPCClientConfig(NamedTuple):
+    """
+    GRPC client configuration options.
+
+    :param secure: Whether to use encrypted protocol (SSL). defaults to True.
+    :type traceroute: bool, optional
+    :param timeout: defaults to 2 seconds. Fail if gateway doesn't receive response within timeout.
+    :type timeout: int, optional
+    :param conn_timeout: defaults to 1. Timeout to retry connection if gRPC is unavailable. 0 is no retry.
+    :type conn_timeout: int, optional
+    :param traceroute: Whether to send receipts back to the gateway from each stage of the graph
+    :type traceroute: bool, optional
+    :param reuse_channel: Whether to reuse the same grpc channel for multiple requests
+    :type traceroute: bool, optional
+    """
     secure: bool = True
-    timeout: int = 2
+    timeout: int = 20
     conn_timeout: int = 1
     traceroute: bool = False
     reuse_channel: bool = True
