@@ -58,13 +58,13 @@ class Index:
               the number of items to batch-process. Defaults to 100.
             * **disable_progress_bar** (*bool*) --
               whether to disable progress bar. Defaults to False.
-            * **grcp_config** (*dict*) --
+            * **grpc_config** (*dict*) --
               See :class:`pinecone.grpc.GRPCClientConfig` for grpc client related configurations.
         """
         self.name = name
         self.batch_size = kwargs.pop("batch_size", 100)
         self.disable_progress_bar = kwargs.pop("disable_progress_bar", False)
-        self.grpc = self._connect(kwargs.pop("grcp_config", {}))
+        self.grpc = self._connect(kwargs.pop("grpc_config", {}))
 
     def _connect(self, grpc_config: dict):
         """Sets up a connection to an index."""
@@ -83,7 +83,11 @@ class Index:
 
     def _make_cursor_config(self, **kwargs) -> dict:
         """Assembles cursor configurations."""
-        config = {"grpc_client": self.grpc, "batch_size": self.batch_size, "disable_progress_bar": self.disable_progress_bar}
+        config = {
+            "grpc_client": self.grpc,
+            "batch_size": self.batch_size,
+            "disable_progress_bar": self.disable_progress_bar,
+        }
         if "batch_size" in kwargs:
             config["batch_size"] = kwargs.pop("batch_size")
         if "disable_progress_bar" in kwargs:
@@ -192,6 +196,9 @@ class Index:
               overrides the number of items to batch-process.
             * **disable_progress_bar** (*bool*) --
               overrides whether to disable the progress bar
+
+        :return: Acknowledgements of items indexed.
+        :rtype: Iterable[UpsertResult]
         """
         return self._upsert(items=items, namespace=namespace, **kwargs).collect()
 
@@ -202,20 +209,11 @@ class Index:
         This method sends a unary gRPC request.
         See :py:meth:`Index.upsert` for details about the parameters.
         """
-        results = self._upsert(items=[item], namespace=namespace, unary=True, disable_progress_bar=True, **kwargs).collect()
+        results = self._upsert(
+            items=[item], namespace=namespace, unary=True, disable_progress_bar=True, **kwargs
+        ).collect()
         return next(iter(results))
 
-    @sentry
-    def stream_upsert(
-        self, items: Iterable[Tuple[str, np.ndarray]], namespace: str = None, **kwargs
-    ) -> Iterator[UpsertResult]:
-        """Upserts items as a stream.
-
-        This method streams the gRPC requests.
-        See :py:meth:`Index.upsert` for details about the parameters.
-        """
-        return self._upsert(items=items, namespace=namespace, **kwargs).stream()
-
     @sentry
     def query(
         self,
@@ -242,6 +240,9 @@ class Index:
               overrides the number of items to batch-process.
             * **disable_progress_bar** (*bool*) --
               overrides whether to disable the progress bar
+
+        :return: For each query, retrieve its nearest neighbors in the index.
+        :rtype: Iterable[QueryResult]
         """
         return self._query(
             queries=queries, namespace=namespace, top_k=top_k, include_data=include_data, **kwargs
@@ -267,24 +268,6 @@ class Index:
         ).collect()
         return next(iter(results))
 
-    @sentry
-    def stream_query(
-        self,
-        queries: Iterable[np.ndarray],
-        namespace: str = None,
-        top_k: int = 10,
-        include_data: bool = False,
-        **kwargs
-    ) -> Iterator[UpsertResult]:
-        """Sends queries as a stream.
-
-        This method streams the gRPC requests.
-        See :py:meth:`Index.query` for details about the parameters.
-        """
-        return self._query(
-            queries=queries, namespace=namespace, top_k=top_k, include_data=include_data, **kwargs
-        ).stream()
-
     @sentry
     def fetch(self, ids: Iterable[str], namespace: str = None, **kwargs) -> Iterable[FetchResult]:
         """Fetches items by their ids.
@@ -301,6 +284,9 @@ class Index:
               overrides the number of items to batch-process.
             * **disable_progress_bar** (*bool*) --
               overrides whether to disable the progress bar
+
+        :return: id-vector pairs stored in the index.
+        :rtype: Iterable[FetchResult]
         """
         return self._fetch(ids=ids, namespace=namespace, **kwargs).collect()
 
@@ -314,15 +300,6 @@ class Index:
         results = self._fetch(ids=[id], namespace=namespace, unary=True, disable_progress_bar=True, **kwargs).collect()
         return next(iter(results))
 
-    @sentry
-    def stream_fetch(self, ids: Iterable[str], namespace: str = None, **kwargs) -> Iterator[FetchResult]:
-        """Fetches items as a stream.
-
-        This method streams gRPC requests.
-        See :py:meth:`Index.fetch` for details about the parameters.
-        """
-        return self._fetch(ids=ids, namespace=namespace, **kwargs).stream()
-
     @sentry
     def delete(self, ids: Iterable[str], namespace: str = None, **kwargs) -> Iterable[DeleteResult]:
         """Deletes items by their ids.
@@ -339,6 +316,9 @@ class Index:
               overrides the number of items to batch-process.
             * **disable_progress_bar** (*bool*) --
               overrides whether to disable the progress bar
+
+        :return: Acknowledgements of items deleted from the index.
+        :rtype: Iterable[DeleteResult]
         """
         return self._delete(ids=ids, namespace=namespace, **kwargs).collect()
 
@@ -352,18 +332,16 @@ class Index:
         results = self._delete(ids=[id], namespace=namespace, unary=True, disable_progress_bar=True, **kwargs).collect()
         return next(iter(results))
 
-    @sentry
-    def stream_delete(self, ids: Iterable[str], namespace: str = None, **kwargs) -> Iterator[DeleteResult]:
-        """Deletes items as a stream.
-
-        This method streams gRPC requests.
-        See :py:meth:`Index.delete` for details about the parameters.
-        """
-        return self._delete(ids=ids, namespace=namespace, **kwargs).stream()
-
     @sentry
     def info(self, namespace: str = None) -> InfoResult:
-        """Returns information about the index."""
+        """Returns information about the index.
+        
+        :param namespace: a partition in an index. Use default namespace when not specified.
+        :type namespace: str, optional
+
+        :return: Information about the index.
+        :rtype: InfoResult
+        """
 
         def _create_info_request(*args) -> "core_pb2.Request":
             path = "write"
