@@ -4,7 +4,6 @@
 
 import os
 import enum
-from pinecone.utils import get_container_memory_limit
 
 RECV_TIMEOUT = 0.5
 SEND_TIMEOUT = 0.5
@@ -17,7 +16,7 @@ AGGREGATOR_NAME = 'aggregator'
 MAX_MSG_SIZE = 64 * 1024 * 1024
 MAX_MSGS_PER_CONNECTION = 100
 MAX_SOCKS_OPEN = 1000
-DNS_TTL = 5
+KUBE_SYNC_TTL = 5  # interval to sync with the kube control plane, reloading DNS and shard config
 
 ZMQ_CONTROL_PORT = os.environ.get('ZMQ_CONTROL_PORT', 5559)
 ZMQ_PORT_IN = os.environ.get('ZMQ_PORT_IN', 5557)
@@ -29,14 +28,30 @@ ENV_VARS = [ZMQ_CONTROL_PORT, ZMQ_PORT_IN, ZMQ_LOG_PORT, PC_CONTROLLER_PORT]
 ZMQ_SECONDARY_PORT = 5559
 MAX_MSGS_PENDING = 1000
 
+SHARD_CONFIG_PATH = '/etc/config'
+NATIVE_SHARD_PATH = '/tmp/config'
+
 MAX_ID_LENGTH = int(os.environ.get("PINECONE_MAX_ID_LENGTH", default="64"))
 MEMORY_UTILIZATION_LIMIT = float(os.environ.get("MEMORY_UTILIZATION_LIMIT", default="0.9"))
+COMPACT_WAL_THRESHOLD = float(os.environ.get("COMPACT_WAL_THRESHOLD", default="0.4"))
+
+
+def get_container_memory_limit():
+    MEMORY_LIMIT_FILE = '/sys/fs/cgroup/memory/memory.limit_in_bytes'
+    if not os.path.exists(MEMORY_LIMIT_FILE):
+        return 0  # no limit
+    with open(MEMORY_LIMIT_FILE) as stat_file:
+        return int(stat_file.read())
+
+
 MEMORY_LIMIT_BYTES = MEMORY_UTILIZATION_LIMIT * get_container_memory_limit()
 
+SHARD_SCALE_THRESHOLD = float(os.environ.get("SHARD_SCALE_THRESHOLD", default="0.8"))
+SHARD_SCALE_BYTES = MEMORY_LIMIT_BYTES * SHARD_SCALE_THRESHOLD
 
-CPU_UNIT = 500
-MEMORY_UNIT = 1875
-DISK_UNIT = 7
+CPU_UNIT = 1000
+MEMORY_UNIT = 4000
+DISK_UNIT = 15
 
 
 class NodeType(str, enum.Enum):
@@ -61,3 +76,9 @@ NODE_TYPE_RESOURCES = {NodeType.STANDARD: {'memory': MEMORY_UNIT, 'cpu': CPU_UNI
                        NodeType.MEMORY2X: {'memory': 4 * MEMORY_UNIT, 'cpu': 2 * CPU_UNIT, 'disk': DISK_UNIT * 4},
                        NodeType.MEMORY4X: {'memory': 8 * MEMORY_UNIT, 'cpu': 4 * CPU_UNIT, 'disk': DISK_UNIT * 8}}
 
+
+class IndexState(enum.Enum):
+    READY = 1  # healthy
+    PENDING = 2  # buffering writes during rebalancing
+    FULL = 3  # cannot accept more writes
+
