@@ -1,10 +1,15 @@
 from typing import BinaryIO
 import google.protobuf.message
 from pinecone.protos import core_pb2
+from pinecone.utils.hash_ring import ConsistentHashRing
+from pinecone.utils import constants
+from pinecone.network.zmq.function_socket import Socket, FunctionSocket
+
 from loguru import logger
 import os
 from . import load_numpy, dump_numpy
 from collections import defaultdict
+import zmq
 
 OFFSET_BYTES = 8
 SIZE_BYTES = 4
@@ -50,7 +55,29 @@ def write_log_entry(log_file: BinaryIO, entry: core_pb2.Request):
     log_file.write(size + entry_bytes + size)
 
 
-def compact_log(log_path: str, tmp_log_path: str, end_file_offset: int):
+def get_sync_sock(context: zmq.Context, fn_sock: FunctionSocket, open_sockets: dict, host: str, native: bool):
+    if host not in open_sockets:
+        sock_spec = fn_sock.socket_spec_for_host(host)
+        sock = sock_spec.zmq(context)
+        conn_str = sock_spec.get_conn_string(native)
+        sock.set_hwm(1)  # needs to be set before bind/connect
+        sock.setsockopt(zmq.RCVBUF, 2 * constants.MAX_MSG_SIZE)
+        sock.setsockopt(zmq.SNDBUF, 2 * constants.MAX_MSG_SIZE)
+        sock.connect(conn_str)
+        open_sockets[host] = sock
+    return open_sockets[host]
+
+
+def compact_log(log_path: str, tmp_log_path: str, end_file_offset: int, hash_ring: ConsistentHashRing = None,
+                cur_shard: int = None, rebalance_sock_spec: Socket = None, native: bool = None):
+    open_sockets = dict()
+    if rebalance_sock_spec:
+        context = zmq.Context()
+        fn_sock = FunctionSocket(rebalance_sock_spec, context, native, init_sockets=False)
+    else:
+        context = None
+        fn_sock = None
+
     with open(log_path, 'rb') as log_file:
         with open(tmp_log_path, 'w+b') as tmp_log_file:
             log_file.seek(end_file_offset)
@@ -68,6 +95,7 @@ def compact_log(log_path: str, tmp_log_path: str, end_file_offset: int):
                             new_entry.index.ids.append(item_id)
                             keep_idx.append(i)
                             ids_seen[entry.namespace].add(item_id)
+
                     data = load_numpy(entry.index.data)
                     new_entry.index.data.CopyFrom(dump_numpy(data[keep_idx, :]))
                     size = len(new_entry.index.ids)
@@ -78,4 +106,16 @@ def compact_log(log_path: str, tmp_log_path: str, end_file_offset: int):
                             ids_seen[entry.namespace].add(item_id)
                     size = len(new_entry.delete.ids)
                 if size > 0:  # only write the request if it has data in it
+                    if hash_ring:
+                        shard_msg = hash_ring.shard_msg(new_entry)
+                        for shard, msg in enumerate(shard_msg):
+                            if shard != cur_shard and len(msg.index.ids) > 0:
+                                msg.client_offset = 0
+                                msg.path = 'none'
+                                remote_host = fn_sock.get_host(shard, replica=0)
+
+                                forward_sock = get_sync_sock(context, fn_sock, open_sockets, remote_host, native)
+                                forward_sock.send(msg.SerializeToString())
+
+                        new_entry = shard_msg[cur_shard]
                     write_log_entry(tmp_log_file, new_entry)
